#
# spec file for package crow-translate
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define  _name  io.crow_translate.CrowTranslate
Name:           crow-translate
Version:        3.1.0
Release:        1.3
Summary:        A Qt GUI for Google, Yandex and Bing translators
License:        GPL-3.0-only
Group:          Productivity/Networking/Web/Frontends
URL:            https://apps.kde.org/crowtranslate
Source0:        https://download.kde.org/stable/crow-translate/%{version}/%{name}-v%{version}.tar.gz
Source1:        https://download.kde.org/stable/crow-translate/%{version}/%{name}-v%{version}.tar.gz.sig
# https://invent.kde.org/sysadmin/release-keyring/-/blob/master/keys/shatur@key1.asc?ref_type=heads
Source2:        crow-translate.keyring
BuildRequires:  cmake >= 3.16.0
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(lept)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(tesseract) >= 4.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
Requires:       gstreamer-plugins-good

%description
A simple and lightweight translator that allows to translate and speak
text using Google, Yandex and Bing written with Qt5.

%lang_package

%prep
%autosetup -p1 -n crow-translate-v%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-qt

%files
%license LICENSES/*
%doc README.md
%{_kf5_applicationsdir}/org.kde.CrowTranslate.desktop
%{_kf5_appstreamdir}/org.kde.CrowTranslate.metainfo.xml
%{_kf5_bindir}/crow
%{_kf5_iconsdir}/hicolor/*/apps/org.kde.CrowTranslate.*
%{_kf5_iconsdir}/hicolor/*/status/org.kde.CrowTranslate-tray-*.*

%files lang -f %{name}.lang

%changelog
* Thu Nov  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 3.1.0. Crow-translate is now hosted on KDE servers.
  Changes since 3.0.0, Check https://apps.kde.org/crowtranslate
  for older changes:
  * Automate fastest Mozhi instance selection.
  * Automatically assign the fastest instance on the first
    startup instead of selecting it randomly.
  * CLI: By default, use the instance from settings.
  * CLI: Verify language codes.
  * CLI: Do not print empty translations on error.
  * CLI: The --help command returns exit code 1.
  * Fix language codes for Persian and Chinese Simplified.
  * Fix loading of Qt translations.
- Drop patches:
  * third-party-library-static.patch
  * cmakelists-txt.patch
  * desktop-file.patch
* Wed Sep 14 2022 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.10.0
- Remove:
  * Fluent-icon-theme-2021-08-15.tar.gz
  * QHotkey-1.4.2.tar.gz
  * QOnlineTranslator-1.5.2.tar.gz
  * QTaskbarControl-2.0.2.tar.gz
  * SingleApplication-3.2.0.tar.gz
  * circle-flags-2.3.0.tar.gz
  * fetchcontent.patch
  * Fix-install-path.patch
- Add patch:
  * third-party-library-static.patch
  * cmakelists-txt.patch
  * desktop-file.patch
* Sat Dec 25 2021 Martin Hauke <mardnh@gmx.de>
- Remove superfluous _service file
- Add patch:
  * fetchcontent.patch (handle bundled dependencies)
* Fri Dec 24 2021 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.9.1
  * Fix actions versions
  * Bump version to 2.9.1
  * Add LibreTranslate and Lingva to popup window
  * Skip app executable for release upload
  * Specify only major action versions
  * Update Italian localization from Crowdin
  * Update Finnish localization from Crowdin
  * Update Finnish localization from Crowdin
  * Update Hungarian localization from Crowdin
  * Update Turkish localization from Crowdin
* Tue Sep  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.1
  Added
  * Uyghur localization.
  * Google: Kinyarwanda, Oriya, Tatar, Turkmen and Uyghur languages.
  Changed
  * All GUI slots now available via D-Bus.
  * Fix saving selected languages.
- Update to version 2.5.0
  Added
  * Add the ability to display only language code on buttons.
  Changed
  * Fix crash at startup with specified languages for Qt < 5.14.
  * Fix Yandex SID parsing.
  * Fix paths in configuration (some settings will be lost).
* Sat Jul  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.1
  * Do not reset languages after reloading settings.
  * Fix duplicated default swap shortcut.
  * Improve global shortcuts error logging.
  * Linux: Fix .desktop file name.
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  Added
  * --brief option to print only translations.
  * The ability to add, remove or reorder used languages.
  * Swap languages shortcut.
  Changed
  * Use https instead of http for all engines.
  * --audio-only option now only plays text.
  * Automatic translation disabled by default.
- Add patch:
  * Fix-install-path.patch
- Switch from qmake to cmake
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  Added
  * The ability to exit the application via D-Bus.
  Changed
  * Return exit code 1 on translation error in CLI.
  * Fix showing the main window if it was minimized.
  * Bing: Fix language auto detection.
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  Added
  * Malay localization.
  Changed
  * Fix disabling transliteration.
  * Minor performance improvements.
  * Fix Malay language flag icon.
  * Force disable embedded global shortcuts on Wayland.
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  Added
  * The ability to disable embedded global shortcuts.
  * D-Bus API.
  * KDE shortcuts support.
  * The ability to simplify source text in query.
  Changed
  * Fix crash on Wayland (still no support for hotkeys and
    selection).
  * Use a simpler and more compatible way to show notifications.
  * Stop speaking source text on change.
  * Google: Fix parsing several sentences in some cases.
  * Google: Fix disabling examples.
  Removed
  * The ability to specify buttons style as useless.
* Sun Nov 24 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.2.3
